@@ -1,10 +1,14 @@
+require('../proposals/array-filtering');
+require('../proposals/array-find-from-last');
 require('../proposals/array-last');
+require('../proposals/array-unique');
 require('../proposals/collection-methods');
 require('../proposals/collection-of-from');
 require('../proposals/keys-composition');
 require('../proposals/math-extensions');
 require('../proposals/math-signbit');
 require('../proposals/number-from-string');
+require('../proposals/number-range');
 require('../proposals/object-iteration');
 require('../proposals/observable');
 require('../proposals/pattern-matching');
